import { test, expect } from '@playwright/test';

// This test suite covers the Read Later functionality
// Ensure the backend is in a clean state before running tests

test.describe('Read Later Section', () => {
	test('should display empty message when no links are saved', async ({ page }) => {
		// Reset the database before test
		await page.goto('/');
		await page.request.post('/api/test/reset');

		await page.goto('/readlist');
		// The empty message in CardList for readlist is "No saved links yet."
		await expect(page.locator('text=No saved links yet.')).toBeVisible();
	});

	test('should add a new URL and display it in the readlist', async ({ page }) => {
		// Reset the database before test
		await page.goto('/');
		await page.request.post('/api/test/reset');

		await page.goto('/readlist');
		const urlInput = page.locator('input[placeholder="Enter a URL to save"]');
		await urlInput.fill('https://example.com');

		const addButton = page.locator('button:has-text("Add Link")');
		await addButton.click();

		// Wait for the card to appear with a link to the readlist detail page
		const cardLink = page.locator('a[href^="/readlist/"]');
		await expect(cardLink).toHaveCount(1);
	});

	test('should delete a saved link', async ({ page }) => {
		// Reset the database before test
		await page.goto('/');
		await page.request.post('/api/test/reset');

		await page.goto('/readlist');
		const urlInput = page.locator('input[placeholder="Enter a URL to save"]');
		await urlInput.fill('https://example.org');

		const addButton = page.locator('button:has-text("Add Link")');
		await addButton.click();

		// Confirm the link is added
		const cardLink = page.locator('a[href^="/readlist/"]');
		await expect(cardLink).toHaveCount(1);

		// Click the delete button corresponding to the saved link
		const deleteButton = page.locator('button:has-text("Delete")').first();
		await deleteButton.click();

		// Wait and check that the card is removed
		await expect(cardLink).toHaveCount(0);
	});
});
